@@ -2,7 +2,7 @@
 ####**********************************************************************
 ####
 ####  RANDOM FORESTS FOR SURVIVAL, REGRESSION, AND CLASSIFICATION (RF-SRC)
-####  Version 1.0.0
+####  Version 1.0.1
 ####
 ####  Copyright 2012, University of Miami
 ####
@@ -158,6 +158,18 @@ avector <- function(x, name = FALSE) {
   }
 }
 
+available <- function (package, lib.loc = NULL, quietly = TRUE) 
+{
+  package <- as.character(substitute(package))
+  installed <- package %in% installed.packages()
+  if (installed) {
+    require(package, quietly = TRUE, character.only = TRUE)
+  }
+  else {
+    return(invisible(FALSE))
+  }
+}
+
 bayes.rule <- function(prob) {
   levels.class <- colnames(prob)
   factor(levels.class[apply(prob, 1, function(x) {
